# Name Initials Tile Generator

This is a tool to generate tiles from name initials.

##### Usage:

`nit [options] name save_path`

`name`: Name to generate initials. <br />
`save_path`: Path where the generated tile should be saved.

###### Options:

`bg`: Background color to be used in tile. <br />
`fg`: Color of the text to be used in tile.

Hope you like it!
